import DefaultLayout from '@/layouts/DefaultLayout/DefaultLayout'
import { getContentTags, getStaticEntries } from '@/lib/content'
import { NextSeo } from 'next-seo'
import Link from 'next/link'
import React from 'react'

export const getStaticProps = () => ({
  props: {
    tags: getContentTags('./content/writing'),
    postEntries: getStaticEntries('./content/writing')
  }
})

export const Title = 'Tags'

export default function Tags ({ tags, postEntries }) {
  return (
    <DefaultLayout>
      <NextSeo
        title={Title}
        openGraph={
          {
            title: Title
          }
        }
      />

      <h1>{Title}</h1>

      <section>
        {Object.keys(tags).sort().map(tag => {
          const posts = postEntries
            .filter(p => p.attributes.tags.includes(tag))
            .sort((a, b) => b.attributes.title > -a.attributes.title)

          return (
            <React.Fragment key={tag}>
              <h2>{tag}</h2>
              <ul>
                {posts.map((post, _) => {
                  return (
                    <li key={post.slug}>
                      <Link href={`/writing/${post.slug}`}>{post.attributes.title}</Link>
                    </li>
                  )
                })}
              </ul>
            </React.Fragment>
          )
        })}
      </section>

    </DefaultLayout>
  )
}
